scope.py — Rucio 1.12.2 documentation

# scope.py

`GET` `/scopes`

  > List all scopes.

  Example request:

      GET /scopes HTTP/1.1

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type:

`POST` `/scopes`

  > Creates scope with given scope name.

  Example request:

      POST /scopes HTTP/1.1

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type:

  Status Codes: | 409 Conflict – ‘Duplicate’: e.args[0][0] 404 Not Found – ‘AccountNotFound’: e.args[0][0] 500 Internal Server Error – e.__class__.__name__: e.args[0][0]

`GET` `/scopes`

  > List all scopes for an account.

  Example request:

      GET /scopes HTTP/1.1

  Example response:

      HTTP/1.1 200 OK
      Vary: Accept
      Content-Type: 'application/json'

  Status Codes: | 404 Not Found – ‘AccountNotFound’: e.args[0][0] 404 Not Found – ‘ScopeNotFound’: ‘no scopes found for account ID ‘%s” % account